@@ -1,4 +1,4 @@
 my_exp_kern <-
 function(a,b,radius=1){
-  exp(-(a-b)*(a-b)/(2*radius))
+  exp(-(a-b)*(a-b)/(2*radius*radius))
 }
